/**
 * 設定ファイルを定義
 * @author yama
 *
 */
package norn.sensor;
import java.io.File;
import java.net.URI;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import java.io.FileNotFoundException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

public class InitSetting {
	// execute path (bin directory parent path on IDE  )
	private String CurrentPath = "";
	// 患者情報XMLのパス
	public String XmlClientPath;
	// 予約情報XMLのパス
	public String XmlReservePath;

	// 予約情報DatabaseHostName
	public String DataBaseHostName;
	// 予約情報DatabaseHostName
	public String DataBasePort;
	// 予約情報DatabaseUser
	public String DataBaseUser;
	// 予約情報DatabasePassword
	public String DataBasePassword;
	// 予約情報DatabaseName
	public String DataBaseName;
	
	/**
	 * コンストラクタで決まる処理を設定
	 * @since 2022/08/23
	 */
	public InitSetting() {
		this.DataBaseHostName = "";
		this.DataBasePort = "";
		this.DataBaseUser = "";
		this.DataBasePassword = "";
		this.DataBaseName = "";
		this.setCurrentPath();
		System.out.println("this.currentPath!!" + this.CurrentPath);
		this.XmlClientPath = "";
		System.out.println(this.CurrentPath);
		try
		{
			this.loadConfigXml();
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}
	
	/**
	 * 
	 */
	public void loadConfigXml() throws FileNotFoundException{
		//		設定ファイルのファイル名を作成
		String confPath = new File(this.CurrentPath + "/init.xml").getPath();
		
		try {
			// DocumentBuilderFactoryのインスタンスを取得する
			DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
			// DocumentBuilderのインスタンスを取得する
			DocumentBuilder builder = factory.newDocumentBuilder();
			// DocumentBuilderにXMLを読み込ませ、Documentを作る
			Document document = builder.parse(confPath);
			// Documentから、ルート要素(BookList)を取得する
			Element settings = document.getDocumentElement();
			// BookList配下にある、Book要素を取得する
			NodeList conf_root = settings.getElementsByTagName("conf");
			// 取得したconfのrootでループする
			for (int i = 0; i < conf_root.getLength(); i++) {
				// conf item要素をElementにキャストする
				Element conf_item = (Element) conf_root.item(i);

				// conf item要素の属性値と、テキストノードの値を取得する
				if(conf_item.getTagName() == "XmlClientPath") {
					this.XmlClientPath = conf_item.getTextContent();					
				}
				// conf item要素の属性値と、テキストノードの値を取得する
				if(conf_item.getTagName() == "XmlReservePath") {
					this.XmlReservePath = conf_item.getTextContent();					
				}
				// conf item要素の属性値と、テキストノードの値を取得する
				if(conf_item.getTagName() == "DataBaseHostName") {
					this.DataBaseHostName = conf_item.getTextContent();					
				}
				// conf item要素の属性値と、テキストノードの値を取得する
				if(conf_item.getTagName() == "DataBasePort") {
					this.DataBasePort = conf_item.getTextContent();					
				}
				// conf item要素の属性値と、テキストノードの値を取得する
				if(conf_item.getTagName() == "DataBaseUser") {
					this.DataBaseUser = conf_item.getTextContent();					
				}
				// conf item要素の属性値と、テキストノードの値を取得する
				if(conf_item.getTagName() == "DataBasePassword") {
					this.DataBasePassword = conf_item.getTextContent();					
				}
				// conf item要素の属性値と、テキストノードの値を取得する
				if(conf_item.getTagName() == "DataBaseName") {
					this.DataBaseName = conf_item.getTextContent();					
				}

			}
		} 
		catch (FileNotFoundException e) {
			//			ParserConfigurationException e => newDocumentBuilder
			//			IOException SAXParseException=> parse
			throw e;
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}
	/**
	 * 実行ファイルの設置場所をプロパティにセット
	 * @throws URISyntaxException 
	 */
	public void setCurrentPath() {
		try {
			String separator = System.getProperty("file.separator");
			URI curPath = InitSetting.class.getProtectionDomain().getCodeSource().getLocation().toURI();
			this.CurrentPath = new File(curPath.getSchemeSpecificPart()).getParent() + separator;
		} catch (Exception e) {
			// linuxならこれで十分取れた　koyama
			this.CurrentPath = new File(InitSetting.class.getProtectionDomain().getCodeSource().getLocation().getPath()).getParent();
		}
	}
	
	/**
	 * コンストラクタで取得設定した実行パスを返す
	 * @return 実行ファイルのあるパスの文字列
	 */
	public String getExecuteDirPath() {
		return this.CurrentPath;
	}
	
	public String getXmlClientPath() {
		return this.XmlClientPath;
	}
	public String getXmlReservePath() {
		return this.XmlReservePath;
	}
	
	public String getHost() {
		return this.DataBaseHostName;
	}
	public String getPort() {
		return this.DataBasePort;
	}
	public int getPortByInt() {
		if (this.DataBasePort.length() != 0 && this.DataBasePort.matches("[0-9]+")) {
			return Integer.valueOf(this.DataBasePort);
		}
		return 0;
	}
	public String getUser() {
		return this.DataBaseUser;
	}
	public String getPwd() {
		return this.DataBasePassword;
	}
	public String getDBN() {
		return this.DataBaseName;
	}
}
